/*
 * Copyright (C) 2000 John David Ratliff, Jason Andrew Fisk, and Hongwei Guan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package controller;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JTextField;

import java.util.StringTokenizer;

import datatypes.Stack;

import model.MVC_Model;

public class TextFieldListener implements ActionListener {
	private MVC_Model model;
	private JTextField textField;
	private Stack upStack;
	private Stack downStack;

	// Editor commands
	private final static char COMMAND_START = '$';
	private final static String INSERT_COMMAND = "INSERT_LINES";
	private final static String DELETE_COMMAND = "DELETE_LINES";
	private final static String SETLINE_COMMAND = "SET_LINE";
	private final static String DONE_COMMAND = "DONE";
	private final static String DISPLAY_COMMAND = "DISPLAY_LINES";
	private final static String INSERT_WORD_COMMAND = "INSERT_WORD";
	private final static String DELETE_WORD_COMMAND = "DELETE_WORD";
	private final static String FIND_COMMAND = "FIND_WORD";
	private final static String REPLACE_COMMAND = "REPLACE_WORD";	
	private final static String LAST_LINE_COMMAND = "LAST_LINE";

	// initilize the TextFieldListener
	public TextFieldListener(MVC_Model model, Stack upStack, Stack downStack, JTextField textField) {
		this.model = model;
		this.upStack = upStack;
		this.downStack = downStack;
		this.textField = textField;
	}

	// what to do when the user hits ENTER
	public void actionPerformed(ActionEvent event) {
		String command;

		while (!this.downStack.isEmpty()) {
			// empty the downStack to be back to '0' as it were
			command = (String)this.downStack.pop();
			this.upStack.push(command);
		}

		command = this.textField.getText();

		if (this.isCommand(command)) {
			// only save real commands
			this.upStack.push(command);
		}

		this.textField.setText("");
		this.model.updateData(command);
	}

	// check to see if the textField contains a command
	private boolean isCommand(String input) {
		StringTokenizer tokens;
		String command;

		tokens = new StringTokenizer(input);

		if (!tokens.hasMoreTokens()) {
			// don't want any exceptions generated due to blank lines
			return false;
		}

		command = tokens.nextToken();

		if (command.charAt(0) == TextFieldListener.COMMAND_START) {
			// we have a possible command
			command = command.substring(1);
		} else {
			// no command identified? not a command then
			return false;
		}

		// if it fits the pattern, it's a command
		if (command.equals(TextFieldListener.INSERT_COMMAND) ||
			command.equals(TextFieldListener.DELETE_COMMAND) ||
			command.equals(TextFieldListener.SETLINE_COMMAND) ||
			command.equals(TextFieldListener.DONE_COMMAND) ||
			command.equals(TextFieldListener.DISPLAY_COMMAND) ||
			command.equals(TextFieldListener.INSERT_WORD_COMMAND) ||
			command.equals(TextFieldListener.DELETE_WORD_COMMAND) ||
			command.equals(TextFieldListener.FIND_COMMAND) ||
			command.equals(TextFieldListener.REPLACE_COMMAND) ||
			command.equals(TextFieldListener.LAST_LINE_COMMAND)) {

			return true;
		}

		// well, all other possibilities must be wrong
		return false;
	}
}
