/*
 * Copyright (C) 2000 John David Ratliff, Jason Andrew Fisk, and Hongwei Guan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package model;

//////////////////////////////////////////////////////////////////////
/**
 * Objects of this class represent the words in a line.  A word
 * consists of three parts: the value, the line, and the index.
 * The value is the String that this word is representing.  The line
 * is the Line to that this word is contained.  Lastly, the index is
 * the zero-based index in the line that this word is at.  Note:  We
 * do not store the index of the word in this object.  However, each
 * occurrence of a given value is unique.  Thus, the wordIndex can be
 * derived by calling line.indexOf(word);.
 */
//////////////////////////////////////////////////////////////////////
public class Word
    {
    private String value;
    private Line line;

    //////////////////////////////////////////////////////////////////////
    /** 
     * This constructor creates a new word object with the given String
     * value, Line, and index.
     *
     * @param value the string value of this word.
     * @param line the line this word is a part of.
     */
    public Word(String value, Line line)
        {
	this.value = value;
	this.line = line;
        }

    //////////////////////////////////////////////////////////////////////
    /**
     * Return the String that this word is representing.
     */
    public String getValue()
        {
	return value;
        }

    //////////////////////////////////////////////////////////////////////    
    /**
     * Return the line that this word is a member of.
     */
    public Line getLine()
        {
	return line;
        }
    //////////////////////////////////////////////////////////////////////  
    /**
     * The string value of the this word object is its value.
     *
     * @param the string value of this word.
     */
    public String toString()
        {
	return value;
        } 	
    }

